@@ -23,7 +23,7 @@ class HeAboutDialog(gtk.Dialog):
         self.set_title('About')
 
         self.image_icon = gtk.Image()
-        self.label_app_name = gtk.Label(app_name)
+        self.label_app_name = gtk.Label()
         self.label_version = gtk.Label()
         self.label_description = gtk.Label()
         self.label_copyright = gtk.Label()
