@@ -317,6 +317,10 @@ class Playlist(ObservableService):
             the appropriate loader function """
         self.__log.debug('Attempting to load %s', filepath)
 
+        # Again, a very KLUDGY workaround (thp, 2010-03-11)
+        if filepath.startswith('/http:/'):
+            filepath = 'http://' + filepath[7:]
+
         error = False
         self.reset_playlist()
         self.filepath = filepath
@@ -517,7 +521,7 @@ class Queue(list, ObservableService):
         assert isinstance( item, PlaylistItem )
         item.playlist_id = self.playlist_id
 
-        if os.path.isfile(item.filepath) and util.is_supported(item.filepath):
+        if os.path.isfile(item.filepath) and util.is_supported(item.filepath) or item.filepath.startswith('http://'):
             self.modified = True
             return True
         else:
